Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/kx132_simpletest.py
    :caption: examples/kx132_simpletest.py
    :lines: 5-

Acc range settings
-------------------

Example showing the Acc range setting

.. literalinclude:: ../examples/kx132_acc_range.py
    :caption: examples/kx132_acc_range.py
    :lines: 5-

Tilt example
-------------------

Example showing the Tilt setting

.. literalinclude:: ../examples/kx132_tilt_example.py
    :caption: examples/kx132_tilt_example.py
    :lines: 5-

Previous Tilt position example
--------------------------------

Example showing the Previous Tilt setting

.. literalinclude:: ../examples/kx132_previous_tilt_position_example.py
    :caption: examples/kx132_previous_tilt_position_example.py
    :lines: 5-

Tap Double Tap example
--------------------------------

Tap Double Tap example

.. literalinclude:: ../examples/kx132_tap_doubletap_example.py
    :caption: examples/kx132_tap_doubletap_example.py
    :lines: 5-

Output Data rate setting
--------------------------

Example showing the Output Data Rate setting

.. literalinclude:: ../examples/kx132_output_data_rate.py
    :caption: examples/kx132_output_data_rate.py
    :lines: 5-

Adp enabled settings
---------------------

Example showing the Adp enabled setting

.. literalinclude:: ../examples/kx132_adp_enabled.py
    :caption: examples/kx132_adp_enabled.py
    :lines: 5-
